@@ -1,6 +1,8 @@
 from matplotlib import pyplot as plt
 import pandas as pd
 
+from tickcounter import plot
+
 class FindingsList(object):
     """
     Store interesting findings.
@@ -13,7 +15,13 @@ class FindingsList(object):
         descrip_ss = pd.Series([i.describe() for i in self.findings_list])
         return descrip_ss
     
+    def describe_short(self):
+        descrip_ss = pd.Series([i.describe_short() for i in self.findings_list])
+        return descrip_ss
+
+    @plot.plotter
     def illustrate(self, n_col=1):
         for i, findings in enumerate(self.findings_list):
-            ax = plt.subplot(len(self.findings_list), 1, i + 1)
+            ax = plt.subplot(len(self.findings_list), n_col, i + 1)
+            ax.set_title(findings.describe_short())
             findings.illustrate(ax=ax)
