@@ -1,5 +1,5 @@
 import pandas as pd
 
-class JSON_Encoder(object):
+class JSONEncoder(object):
   # Encode using JSON, create a MultiEncoder with needed Encoder objects under the hood.
   pass
\ No newline at end of file
